@@ -49,6 +49,8 @@ typedef struct _GogStyledObject	GogStyledObject;
 typedef struct _GogAxisBase GogAxisBase;
 typedef struct _GogAxis		GogAxis;
 typedef struct _GogAxisLine	GogAxisLine;
+typedef struct _GogAxisColorMap GogAxisColorMap;
+typedef struct _GogColorScale GogColorScale;
 typedef struct _GogGrid		GogGrid;
 typedef struct _GogGridLine	GogGridLine;
 typedef struct _GogErrorBar	GogErrorBar;
@@ -234,6 +236,8 @@ extern int goffice_graph_debug_level;
 G_END_DECLS
 
 #include <goffice/goffice.h>
+#include <goffice/data/goffice-data.h>
+#include <goffice/math/goffice-math.h>
 
 #include <goffice/graph/gog-object.h>
 #include <goffice/graph/gog-styled-object.h>
@@ -251,8 +255,11 @@ G_END_DECLS
 #include <goffice/graph/gog-chart-impl.h>
 #include <goffice/graph/gog-chart-map.h>
 #include <goffice/graph/gog-chart-map-3d.h>
+#include <goffice/graph/gog-axis-color-map.h>
+#include <goffice/graph/gog-color-scale.h>
 #ifdef GOFFICE_WITH_GTK
 #include <goffice/graph/gog-child-button.h>
+#include <goffice/graph/gog-color-scale.h>
 #include <goffice/graph/gog-data-allocator.h>
 #endif
 #ifdef GOFFICE_WITH_LASEM
