@@ -1,3 +1,4 @@
+/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * go-format-sel.c: A widget to select a format
  *
@@ -90,7 +91,9 @@ typedef enum {
 	F_SYMBOL_LABEL,		F_SYMBOL,
 	F_ENTRY,
 	F_LIST_LABEL,		F_LIST_SCROLL,		F_LIST,
-	F_DECIMAL_SPIN,		F_ENGINEERING_BUTTON,
+	F_DECIMAL_SPIN,		
+	F_FORCE_EXPONENT_SIGN_BUTTON,
+	F_ENGINEERING_BUTTON,
 	F_SUPERSCRIPT_BUTTON,	F_SUPERSCRIPT_HIDE_1_BUTTON,
 	F_SI_BUTTON,            F_SI_CUSTOM_UNIT_BUTTON,
 	F_SI_SI_UNIT_BUTTON,	F_SI_UNIT_COMBO,
@@ -466,6 +469,15 @@ cb_separator_toggle (GtkWidget *w, GOFormatSel *gfs)
 	draw_format_preview (gfs, TRUE);
 }
 
+static void
+cb_force_exponent_sign_toggle (GtkWidget *w, GOFormatSel *gfs)
+{
+	gfs->format.details.exponent_sign_forced = 
+		gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (w));
+
+	draw_format_preview (gfs, TRUE);
+}
+
 static void
 cb_engineering_toggle (GtkWidget *w, GOFormatSel *gfs)
 {
@@ -780,10 +792,8 @@ fmt_dialog_enable_widgets (GOFormatSel *gfs, int page)
 			F_FRACTION_MIN_DENOM_DIGITS_LABEL,
 			F_FRACTION_MAX_DENOM_DIGITS,
 			F_FRACTION_MIN_DENOM_DIGITS,
-#ifdef ALLOW_PI_SLASH
 			F_FRACTION_PI_SCALE,
 			F_BASE_SEPARATOR,
-#endif
 			F_MAX_WIDGET
 		},
 		/* Scientific */
@@ -792,17 +802,16 @@ fmt_dialog_enable_widgets (GOFormatSel *gfs, int page)
 			F_DECIMAL_GRID,
 			F_DECIMAL_LABEL,
 			F_DECIMAL_SPIN,
+			F_FORCE_EXPONENT_SIGN_BUTTON,
 			F_ENGINEERING_BUTTON,
 			F_SUPERSCRIPT_BUTTON,
 			F_SUPERSCRIPT_HIDE_1_BUTTON,
 			F_EXP_DIGITS,
 			F_EXP_DIGITS_LABEL,
-#ifdef ALLOW_SI_APPEND
 			F_SI_BUTTON,
 			F_SI_CUSTOM_UNIT_BUTTON,
 			F_SI_SI_UNIT_BUTTON,
 			F_SI_UNIT_COMBO,
-#endif
 			F_MAX_WIDGET
 		},
 		/* Text */
@@ -944,24 +953,19 @@ stays:
 			break;
 
 		case F_SUPERSCRIPT_BUTTON:
-#ifdef ALLOW_EE_MARKUP
 			if (gfs->show_format_with_markup) {
 				gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w),
 							      gfs->format.details.use_markup);
 			} else
-#endif
 				show_widget = FALSE;
 			break;
 
 		case F_SUPERSCRIPT_HIDE_1_BUTTON:
-#ifdef ALLOW_EE_MARKUP
 			if (gfs->show_format_with_markup) {
-
 				gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w),
 							      gfs->format.details.simplify_mantissa);
 				gtk_widget_set_sensitive (w, gfs->format.details.use_markup);
 			} else
-#endif
 				show_widget = FALSE;
 			break;
 
@@ -980,88 +984,83 @@ stays:
 			break;
 
 		case F_SI_BUTTON:
-#ifdef ALLOW_SI_APPEND
+			show_widget = go_format_allow_si ();
 			gtk_toggle_button_set_active
 				(GTK_TOGGLE_BUTTON (w),
-				 gfs->format.details.append_SI);
-#else
-			gtk_toggle_button_set_active
-				(GTK_TOGGLE_BUTTON (w), FALSE);
-			show_widget = FALSE;
-#endif
+				 show_widget && gfs->format.details.append_SI);
 			break;
 
 		case F_SI_CUSTOM_UNIT_BUTTON:
-#ifdef ALLOW_SI_APPEND
-			gtk_widget_set_sensitive (w, gfs->format.details.append_SI);
+			show_widget = go_format_allow_si ();
+			gtk_widget_set_sensitive
+				(w,
+				 show_widget && gfs->format.details.append_SI);
 			/* This is set through F_SI_UNIT_COMBO */
-#else
-			show_widget = FALSE;
-#endif
 			break;
 
 		case F_SI_SI_UNIT_BUTTON:
-#ifdef ALLOW_SI_APPEND
-			gtk_widget_set_sensitive (w, gfs->format.details.append_SI);
+			show_widget = go_format_allow_si ();
+			gtk_widget_set_sensitive
+				(w,
+				 show_widget && gfs->format.details.append_SI);
 			/* This is set through F_SI_UNIT_COMBO */
-#else
-			show_widget = FALSE;
-#endif
 			break;
 
-		case F_SI_UNIT_COMBO: {
-#ifdef ALLOW_SI_APPEND
-			gint row = -1;
-			guint ii;
+		case F_SI_UNIT_COMBO:
+			show_widget = go_format_allow_si ();
+			if (show_widget) {
+				gint row = -1;
+				guint ii;
 
-			gtk_widget_set_sensitive (w, gfs->format.details.append_SI);
-			if (gfs->format.details.appended_SI_unit != NULL) {
-				char const *unit = gfs->format.details.appended_SI_unit;
-				if (unit[0] == 'g' && unit[1] == 0)
-					unit = "kg";
-				for (ii = 0; ii < G_N_ELEMENTS (si_units); ii++)
-					if (0 == strcmp (si_units[ii].unit, unit)) {
-						row = (gint)ii;
-						break;
-					}
-			}
-
-			if (row == -1) {
-				if (gfs->format.details.appended_SI_unit == NULL) {
-					gtk_button_set_label
-						(GTK_BUTTON (gfs->format.widget[F_SI_CUSTOM_UNIT_BUTTON]),
-						 _("Append no further unit."));
-					g_free (gfs->format.default_si_unit);
-					gfs->format.default_si_unit = NULL;
-				} else {
-					gchar *label;
-					gfs->format.default_si_unit
-						= g_strdup (gfs->format.details.appended_SI_unit);
-					label = g_strdup_printf (_("Append \'%s\'."),
-								 gfs->format.default_si_unit);
-					gtk_button_set_label
-						(GTK_BUTTON (gfs->format.widget[F_SI_CUSTOM_UNIT_BUTTON]),
-						 label);
-					g_free (label);
+				gtk_widget_set_sensitive (w, gfs->format.details.append_SI);
+				if (gfs->format.details.appended_SI_unit != NULL) {
+					char const *unit = gfs->format.details.appended_SI_unit;
+					if (unit[0] == 'g' && unit[1] == 0)
+						unit = "kg";
+					for (ii = 0; ii < G_N_ELEMENTS (si_units); ii++)
+						if (0 == strcmp (si_units[ii].unit, unit)) {
+							row = (gint)ii;
+							break;
+						}
 				}
-			} else
-				gtk_combo_box_set_active_id (GTK_COMBO_BOX (w), si_units[row].unit);
 
-			if (row >= 0)
-				gtk_toggle_button_set_active
-					(GTK_TOGGLE_BUTTON (gfs->format.widget[F_SI_SI_UNIT_BUTTON]),
-					 TRUE);
-			else
-				gtk_toggle_button_set_active
-					(GTK_TOGGLE_BUTTON (gfs->format.widget[F_SI_CUSTOM_UNIT_BUTTON]),
-					 TRUE);
+				if (row == -1) {
+					if (gfs->format.details.appended_SI_unit == NULL) {
+						gtk_button_set_label
+							(GTK_BUTTON (gfs->format.widget[F_SI_CUSTOM_UNIT_BUTTON]),
+							 _("Append no further unit."));
+						g_free (gfs->format.default_si_unit);
+						gfs->format.default_si_unit = NULL;
+					} else {
+						gchar *label;
+						gfs->format.default_si_unit
+							= g_strdup (gfs->format.details.appended_SI_unit);
+						label = g_strdup_printf (_("Append \'%s\'."),
+									 gfs->format.default_si_unit);
+						gtk_button_set_label
+							(GTK_BUTTON (gfs->format.widget[F_SI_CUSTOM_UNIT_BUTTON]),
+							 label);
+						g_free (label);
+					}
+				} else
+					gtk_combo_box_set_active_id (GTK_COMBO_BOX (w), si_units[row].unit);
 
+				if (row >= 0)
+					gtk_toggle_button_set_active
+						(GTK_TOGGLE_BUTTON (gfs->format.widget[F_SI_SI_UNIT_BUTTON]),
+						 TRUE);
+				else
+					gtk_toggle_button_set_active
+						(GTK_TOGGLE_BUTTON (gfs->format.widget[F_SI_CUSTOM_UNIT_BUTTON]),
+						 TRUE);
+			}
+			break;
 
-#else
-				show_widget = FALSE;
-#endif
+		case F_FORCE_EXPONENT_SIGN_BUTTON:
+			gtk_toggle_button_set_active
+				(GTK_TOGGLE_BUTTON (w),
+				 gfs->format.details.exponent_sign_forced);
 			break;
-		}
 
 		case F_ENGINEERING_BUTTON:
 			gtk_toggle_button_set_active
@@ -1132,13 +1131,10 @@ stays:
 			break;
 
 		case F_FRACTION_PI_SCALE:
+			show_widget = go_format_allow_pi_slash ();
 			gtk_toggle_button_set_active
-#ifdef ALLOW_PI_SLASH
 				(GTK_TOGGLE_BUTTON (w),
-				 gfs->format.details.pi_scale);
-#else
-				(GTK_TOGGLE_BUTTON (w), FALSE);
-#endif
+				 show_widget && gfs->format.details.pi_scale);
 			break;
 
 		default:
@@ -1442,6 +1438,7 @@ nfs_init (GOFormatSel *gfs)
 		"format_list_scroll",
 		"format_list",
 		"format_number_decimals",
+		"format_force_exponent_sign_button",
 		"format_engineering_button",
 		"format_superscript_button",
 		"format_superscript_hide_1_button",
@@ -1596,6 +1593,8 @@ nfs_init (GOFormatSel *gfs)
 		G_CALLBACK (cb_exp_digits_changed), gfs);
 	g_signal_connect (G_OBJECT (gfs->format.widget[F_SEPARATOR]), "toggled",
 		G_CALLBACK (cb_separator_toggle), gfs);
+	g_signal_connect (G_OBJECT (gfs->format.widget[F_FORCE_EXPONENT_SIGN_BUTTON]), "toggled",
+		G_CALLBACK (cb_force_exponent_sign_toggle), gfs);
 	g_signal_connect (G_OBJECT (gfs->format.widget[F_ENGINEERING_BUTTON]), "toggled",
 		G_CALLBACK (cb_engineering_toggle), gfs);
 	g_signal_connect (G_OBJECT (gfs->format.widget[F_SUPERSCRIPT_BUTTON]), "toggled",
@@ -1790,7 +1789,8 @@ go_format_sel_new_full (gboolean use_markup)
 	gfs = g_object_new (GO_TYPE_FORMAT_SEL, NULL);
 
 	if (gfs != NULL)
-		gfs->show_format_with_markup = use_markup;
+		gfs->show_format_with_markup =
+			go_format_allow_ee_markup () && use_markup;
 
 	return (GtkWidget *) gfs;
 }
